@@ -19,6 +19,7 @@
 
 import logging
 import os
+from pathlib import Path
 import pexpect
 import subprocess
 import sys
@@ -86,6 +87,7 @@ class BootToShellTest(unittest.TestCase):
 
     def setUp(self):
         self.startTime = time.time()
+        self.root = Path(os.environ.get('DEB_EDK2_ROOT', '/'))
 
     def tearDown(self):
         t = time.time() - self.startTime
@@ -266,14 +268,14 @@ class BootToShellTest(unittest.TestCase):
         )
         shim = SignedBinary(
             get_local_shim_path('AA64', signed=False),
-            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
-            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
+            self.root / "usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
+            self.root / "usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
             "snakeoil",
         )
         grub = SignedBinary(
             get_local_grub_path('AA64', signed=False),
-            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
-            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
+            self.root / "usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
+            self.root / "usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
             "snakeoil",
         )
         iso = GrubShellBootableIsoImage('AA64', shim.path, grub.path)
@@ -437,14 +439,14 @@ class BootToShellTest(unittest.TestCase):
         )
         shim = SignedBinary(
             get_local_shim_path('X64', signed=False),
-            "/usr/share/ovmf/PkKek-1-snakeoil.key",
-            "/usr/share/ovmf/PkKek-1-snakeoil.pem",
+            self.root / "usr/share/ovmf/PkKek-1-snakeoil.key",
+            self.root / "usr/share/ovmf/PkKek-1-snakeoil.pem",
             "snakeoil",
         )
         grub = SignedBinary(
             get_local_grub_path('X64', signed=False),
-            "/usr/share/ovmf/PkKek-1-snakeoil.key",
-            "/usr/share/ovmf/PkKek-1-snakeoil.pem",
+            self.root / "usr/share/ovmf/PkKek-1-snakeoil.key",
+            self.root / "usr/share/ovmf/PkKek-1-snakeoil.pem",
             "snakeoil",
         )
         iso = GrubShellBootableIsoImage('X64', shim.path, grub.path)
